import 'dart:async';
import 'dart:core';
import 'dart:io';

import 'package:device_info/device_info.dart';
import 'package:mmoo_base/api/address.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:package_info/package_info.dart';

///单例的公共类-系统配置，充值，礼物
class AppInfoUtil {
  factory AppInfoUtil() => _getInstance()!;

  static AppInfoUtil? get instance => _getInstance();
  static AppInfoUtil? _instance;

  AppInfoUtil._internal();

  static AppInfoUtil? _getInstance() {
    if (_instance == null) _instance = AppInfoUtil._internal();
    return _instance;
  }

  late IosDeviceInfo iosDeviceInfo;
  late AndroidDeviceInfo androidDeviceInfo;
  late PackageInfo packageInfo;

  Future<bool> getDeviceInfo() async {
    DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();
    if (Platform.isAndroid) {
      androidDeviceInfo = await deviceInfo.androidInfo;
    } else if (Platform.isIOS) {
      iosDeviceInfo = await deviceInfo.iosInfo;
      FlutterSecureStorage storage = FlutterSecureStorage();
      Address.appId = await storage.read(key: Address.iosId);
      if (Address.appId?.isEmpty != false) {
        Address.appId = iosDeviceInfo.identifierForVendor;
        storage.write(key: Address.iosId, value: Address.appId);
      }
    }
    packageInfo = await PackageInfo.fromPlatform();
    return true;
  }
}
